@@ -25,7 +25,11 @@ initui (void)
 	
     pyui_register_classes (d);
     pyui_add_constants (m, "GNOME_");
-
+    
+    PyDict_SetItemString(d, "PAD", PyInt_FromLong(GNOME_PAD));
+    PyDict_SetItemString(d, "PAD_SMALL", PyInt_FromLong(GNOME_PAD_SMALL));
+    PyDict_SetItemString(d, "PAD_BIG", PyInt_FromLong(GNOME_PAD_BIG));
+        
     gnome_program_module_register(LIBGNOMEUI_MODULE);
 	
     if (PyErr_Occurred ()) {
